@@ -14,7 +14,7 @@ use Socket;
 use Storable;
 use vars qw($VERSION);
 
-$VERSION = '1.20';
+$VERSION = '1.22';
 
 sub spawn {
   my $package = shift;
@@ -502,7 +502,7 @@ sub _process_queue {
   my ($kernel,$self) = @_[KERNEL,OBJECT];
   return if $self->{paused};
   my $item = shift @{ $self->{_mail_queue} };
-  $kernel->delay( '_process_queue', 120 );
+  $kernel->delay_set( '_process_queue', 120 );
   return unless $item;
   $item->{attempt}++;
   # Process Recipient Handlers here
@@ -600,14 +600,14 @@ sub _smtp_send_relay {
 sub _smtp_send_success {
   my ($kernel,$self,$item) = @_[KERNEL,OBJECT,ARG0];
   $self->send_event( 'smtpd_send_success', $item->{uid} );
-  $kernel->yield( '_process_queue' );
+  $kernel->delay_set( '_process_queue', 20 );
   return;
 }
 
 sub _smtp_send_failure {
   my ($kernel,$self,$item,$error) = @_[KERNEL,OBJECT,ARG0,ARG1];
   $self->send_event( 'smtpd_send_failed', $item->{uid}, $error );
-  $kernel->yield( '_process_queue' );
+  $kernel->delay_set( '_process_queue', 20 );
   if ( $error->{SMTP_Server_Error} and $error->{SMTP_Server_Error} =~ /^5/ ) {
 	return;
   }
